package org.alfresco.bm.event.selector;



/**
 * Represents a full response from an event processor:
 * a success/failure indication, a response message and the raw response data.
 *  
 * @author steveglover
 * @since 1.3
 */
public class EventProcessorResponse
{
    private String message;
    private boolean success;
    private Object responseData;
    private boolean persistAsString = false;

    /**
     * Constructor for an event response
     * 
     * @param message              any message associated with the response
     * @param success              whether the event processing was successful or not
     * @param responseData         any other data associated with the response
     */
    public EventProcessorResponse(String message, boolean success, Object responseData)
    {
        this.message = message;
        this.success = success;
        this.responseData = responseData;
    }

    /**
     * Constructor for an event response
     * 
     * @param message              any message associated with the response
     * @param success              whether the event processing was successful or not
     * @param responseData         any other data associated with the response
     * @param forceStringResponse  call 
     */
    public EventProcessorResponse(String message, boolean success, Object responseData, boolean persistAsString)
    {
    	this(message, success, responseData);
        this.persistAsString = persistAsString;
    }

    @Override
    public String toString()
    {
        StringBuilder builder = new StringBuilder();
        builder.append("EventProcessorResponse [message=");
        builder.append(message);
        builder.append(", success=");
        builder.append(success);
        builder.append(", responseData=");
        builder.append(responseData);
        builder.append("]");
        return builder.toString();
    }

    public String getMessage()
    {
        return message;
    }
    
    public boolean isSuccess()
    {
        return success;
    }
    
    public Object getResponseData()
    {
    	return responseData;
    }

	public boolean isPersistAsString()
	{
		return persistAsString;
	}
}
